/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hdiv.web.servlet.tags.form;

import javax.servlet.jsp.JspException;

import org.hdiv.dataComposer.IDataComposer;
import org.springframework.web.servlet.tags.form.RadioButtonTag;
import org.springframework.web.servlet.tags.form.TagWriter;

/**
 * Databinding-aware JSP tag for rendering an HTML '<code>input</code>'
 * element with a '<code>type</code>' of '<code>radio</code>'.
 *
 * <p>Rendered elements are marked as 'checked' if the configured
 * {@link #setValue(Object) value} matches the {@link #getValue bound value}.
 *
 * <p>A typical usage pattern will involved multiple tag instances bound
 * to the same property but with different values.
 * 
 * @author Gorka Vicente
 * @since HDIV 2.0.3
 * @see org.springframework.web.servlet.tags.form.RadioButtonTag
 */
public class RadioButtonTagHDIV extends RadioButtonTag {
	
	private static final String DATA_COMPOSER = "dataComposer";

 
	/**
	 * Renders the '<code>input(radio)</code>' element with the configured
	 * {@link #setValue(Object) value}. Marks the element as checked if the
	 * value matches the {@link #getValue bound value}.
	 */
	protected int writeTagContent(TagWriter tagWriter) throws JspException {
		
		tagWriter.startTag("input");
		writeDefaultAttributes(tagWriter);
		tagWriter.writeAttribute("type", "radio");

		Object value = getValue();
		Object resolvedValue = evaluate("value", value);
		
		IDataComposer dataComposer = (IDataComposer) this.pageContext.getRequest().getAttribute(DATA_COMPOSER);		
		String displayValue = getDisplayString(resolvedValue, getPropertyEditor());
		String hdivValue = dataComposer.compose(super.getName(), displayValue, false);		
		
		tagWriter.writeAttribute("value", hdivValue);

		if (SelectedValueComparatorHDIV.isSelected(getBindStatus(), resolvedValue)) {
			tagWriter.writeAttribute("checked", "checked");
		}
		
		if (getLabel() != null) {
			tagWriter.appendValue(getLabel().toString());
		}

		tagWriter.endTag();
		return EVAL_PAGE;
	}

}
