/*
 * Copyright 2002-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hdiv.web.servlet.tags.form;

import javax.servlet.jsp.JspException;

import org.hdiv.dataComposer.IDataComposer;
import org.springframework.util.ObjectUtils;
import org.springframework.web.servlet.tags.form.RadioButtonsTag;
import org.springframework.web.servlet.tags.form.TagWriter;

/**
 * Databinding-aware JSP tag for rendering multiple HTML '<code>input</code>'
 * elements with a '<code>type</code>' of '<code>radio</code>'.
 *
 * <p>Rendered elements are marked as 'checked' if the configured
 * {@link #setItems(Object) value} matches the bound value.
 *
 * @author Gorka Vicente
 * @since 2.0.3
 */
public class RadioButtonsTagHDIV extends RadioButtonsTag {

	private static final String DATA_COMPOSER = "dataComposer";
	

	private void writeRadioButtonTag(TagWriter tagWriter, Object value, Object label, int itemIndex) throws JspException {
		
		IDataComposer dataComposer = (IDataComposer) this.pageContext.getRequest().getAttribute(DATA_COMPOSER);
		
		tagWriter.startTag(getElement());
		if (itemIndex > 0 && this.getDelimiter() != null) {
			tagWriter.appendValue(ObjectUtils.getDisplayString(evaluate("delimiter", this.getDelimiter())));
		}
		tagWriter.startTag("input");
		writeDefaultAttributes(tagWriter);
		tagWriter.writeAttribute("type", "radio");
		
		String displayValue = getDisplayString(value, getPropertyEditor());
		String hdivValue = dataComposer.compose(super.getName(), displayValue, false);
		
		tagWriter.writeAttribute("value", hdivValue);
		if (SelectedValueComparatorHDIV.isSelected(getBindStatus(), value)) {
			tagWriter.writeAttribute("checked", "checked");
		}
		tagWriter.appendValue(label.toString());
		tagWriter.endTag();
		tagWriter.endTag();
	}

}
